@@ -1,7 +1,11 @@
+# Copyrights 1999,2001-2007 by Mark Overmeer.
+#  For other contributors see ChangeLog.
+# See the manual pages for details on the licensing terms.
+# Pod stripped from pm file by OODoc 1.00.
 
 package MIME::Types;
 use vars '$VERSION';
-$VERSION = '1.16';
+$VERSION = '1.20';
 
 use strict;
 
@@ -42,7 +46,7 @@ sub init($)
 
             next if $args->{only_complete} && ! $extensions;
             my $extent = $extensions ? [ split /\,/, $extensions ] : undef;
-                    
+
             my $simplified = MIME::Type->simplified($type);
             push @{$list{$simplified}}, MIME::Type->new
               ( type       => $type
@@ -126,7 +130,7 @@ sub types
     $self->create_type_index unless keys %type_index;
     return values %type_index;
 }
-                                                                                
+
 #-------------------------------------------
 
 
@@ -136,7 +140,7 @@ sub extensions
 
     return keys %type_index;
 }
-                                                                                
+
 #-------------------------------------------
 
 
@@ -205,12 +209,13 @@ CROAK
 # Internet media type registry is at
 # http://www.iana.org/assignments/media-types/
 
-$mime_type_definitions = <<MIMETYPES;
+$mime_type_definitions = <<__MIMETYPES__;
 application/activemessage
 application/andrew-inset		ez
 application/appledouble					base64
 application/applefile					base64
 application/atomicmail
+application/atom+xml			atom		8bit
 application/batch-SMTP
 application/beep+xml
 application/cals-1840
@@ -249,7 +254,7 @@ application/news-message-id
 application/news-transmission
 application/ocsp-request	orq
 application/ocsp-response	ors
-application/octet-stream	bin,dms,lha,lzh,exe,class,ani,pgp	base64
+application/octet-stream bin,dms,lha,lzh,exe,class,ani,pgp,so,dll,dmg	base64
 application/oda			oda
 application/ogg			ogg
 application/parityfec
@@ -272,6 +277,7 @@ application/prs.cww		cw,cww
 application/prs.nprend		rnd,rct
 application/prs.plucker
 application/qsig
+application/rdf+xml		rdf				8bit
 application/reginfo+xml
 application/remote-printing
 application/riscos
@@ -370,7 +376,7 @@ application/vnd.groove-tool-template
 application/vnd.groove-vcard
 application/vnd.hbci		hbci,hbc,kom,upa,pkd,bpd
 application/vnd.hhe.lesson-player	les
-application/vnd.hp-HPGL		plt,hpgl	
+application/vnd.hp-HPGL		plt,hpgl
 application/vnd.hp-hpid
 application/vnd.hp-hps
 application/vnd.hp-PCL
@@ -412,6 +418,8 @@ application/vnd.kde.kword	kwd,kwt
 application/vnd.kenameapp	htke
 application/vnd.kidspiration	kia
 application/vnd.Kinar		kne,knp,sdf
+application/vnd.google-earth.kml+xml			kml	8bit
+application/vnd.google-earth.kmz			kmz	8bit
 application/vnd.koan
 application/vnd.liberty-request+xml
 application/vnd.llamagraphics.life-balance.desktop	lbd
@@ -597,7 +605,7 @@ application/x-dxf
 application/x-excel
 application/x-fractals
 application/x-futuresplash	spl
-application/x-ghostview		
+application/x-ghostview
 application/x-gtar		gtar,tgz,tbz2,tbz		base64
 application/x-gunzip
 application/x-gzip		gz				base64
@@ -620,8 +628,8 @@ application/x-mac-compactpro	cpt
 application/x-maker		frm,maker,frame,fm,fb,book,fbdoc
 application/x-mathcad	# mcd, but there is also vnd.mcd
 application/x-mif		mif
-application/xml
-application/xml-dtd
+application/xml			xml xsl				8bit
+application/xml-dtd		dtd				8bit
 application/xml-external-parsed-entity
 application/x-msaccess			mda,mdb,mde,mdf		base64
 application/x-msdos-program	cmd,bat				8bit
@@ -642,6 +650,7 @@ application/x-set
 application/x-shar		shar				8bit
 application/x-shockwave-flash	swf
 application/x-sh		sh				8bit
+application/xslt+xml		xslt				8bit
 application/x-SLA
 application/x-solids
 application/x-spss		sav,sbs,sps,spo,spp
@@ -667,7 +676,8 @@ application/x-x400-bp
 application/x-x509-ca-cert	crt				base64
 application/zip			zip				base64
 audio/32kadpcm
-audio/3gpp			3gpp
+audio/3gpp
+audio/3gpp2
 audio/AMR			amr				base64
 audio/AMR-WB			awb				base64
 audio/basic			au,snd				base64
@@ -727,7 +737,7 @@ audio/vnd.nuera.ecelp4800	ecelp4800
 audio/vnd.nuera.ecelp7470	ecelp7470
 audio/vnd.nuera.ecelp9600	ecelp9600
 audio/vnd.octel.sbc
-audio/vnd.qcelp	
+audio/vnd.qcelp
 audio/vnd.rhetorex.32kadpcm
 audio/vnd.sealedmedia.softseal.mpeg	smp3,smp,s1m
 audio/vnd.vmx.cvsd
@@ -752,6 +762,7 @@ image/naplps
 image/png			png				base64
 image/prs.btif
 image/prs.pti
+image/svg+xml			svg				8bit
 image/t38
 image/targa			tga
 image/tiff-fx
@@ -866,12 +877,13 @@ text/vnd.wap.sl				sl
 text/vnd.wap.wmlscript			wmls
 text/vnd.wap.wml			wml
 text/xml-external-parsed-entity
-text/xml				xml,dtd				8bit
+text/xml
 text/x-setext				etx
 text/x-sgml				sgml,sgm			8bit
 text/x-vCalendar			vcs				8bit
 text/x-vCard				vcf				8bit
-video/3gpp				3gp,3gpp
+video/3gpp				3gp,3gpp			base64
+video/3gpp2				3g2,3gpp2			base64
 video/BMPEG
 video/BT656
 video/CelB
@@ -908,6 +920,7 @@ video/vnd.sealed.mpeg4			smpg,s14
 video/vnd.sealed.swf			sswf,ssw
 video/vnd.vivo				viv,vivo
 video/x-fli				fli				base64
+video/x-flv				flv				base64
 video/x-ms-asf				asf,asx
 video/x-ms-wmv				wmv
 video/x-msvideo				avi				base64
@@ -923,6 +936,6 @@ x-world/x-vrml				wrl,vrml
 vms:text/plain				doc				8bit
 mac:application/x-macbase64		bin
 
-MIMETYPES
+__MIMETYPES__
 
 1;
